@@ -1,5 +1,5 @@
 from django.core.urlresolvers import reverse, NoReverseMatch
-from django.forms import widgets
+from django.forms import widgets, Media
 from django.utils.safestring import mark_safe
 from django.conf import settings
 import json
@@ -8,6 +8,9 @@ import json
 class FroalaEditor(widgets.Textarea):
     def __init__(self, *args, **kwargs):
         self.options = kwargs.pop('options', {})
+        self.plugins = kwargs.pop('plugins', {})
+        self.theme = kwargs.pop('theme', None)
+        self.include_jquery = kwargs.pop('include_jquery', True)
         self.image_upload = kwargs.pop('image_upload', True)
         self.file_upload = kwargs.pop('file_upload', True)
         super(FroalaEditor, self).__init__(*args, **kwargs)
@@ -17,6 +20,7 @@ class FroalaEditor(widgets.Textarea):
         default_options = {
             'inlineMode': False,
         }
+
         try:
             image_upload_url = reverse('froala_editor_image_upload')
             default_options['imageUploadURL'] = image_upload_url
@@ -24,6 +28,10 @@ class FroalaEditor(widgets.Textarea):
             default_options['imageUpload'] = False
         settings_options = getattr(settings, 'FROALA_EDITOR_OPTIONS', {})
         options = dict(default_options.items() + settings_options.items() + self.options.items())
+
+        if self.theme:
+            options['theme'] = self.theme
+
         return json.dumps(options)
 
 
@@ -42,8 +50,22 @@ class FroalaEditor(widgets.Textarea):
         </script>""" % (el_id, options)
         return str
 
-    class Media:
+    def _media(self):
         css = {
-            'all': ('froala_editor/css/font-awesome.min.css', 'froala_editor/css/froala_editor.min.css', 'froala_editor/css/froala-django.css')
+        'all': ('froala_editor/css/font-awesome.min.css', 'froala_editor/css/froala_editor.min.css', 'froala_editor/css/froala-django.css')
         }
-        js = ('froala_editor/js/jquery.min.js', 'froala_editor/js/froala_editor.min.js',)
+        js = ('froala_editor/js/froala_editor.min.js',)
+
+        if self.include_jquery:
+            print self.include_jquery
+            js = ('froala_editor/js/libs/jquery-1.10.2.min.js',) + js
+
+        if self.theme:
+            css['all'] += ('froala_editor/css/themes/'+self.theme+'.css',)
+
+        for plugin in self.plugins:
+            js += ('froala_editor/js/plugins/'+plugin+'.min.js',)
+
+        return Media(css=css, js=js)
+
+    media = property(_media)
